Improve this Doc

# Error: $q:norslvr
No resolver function passed to $Q

    Expected resolverFn, got '{0}'

## Description

Occurs when calling creating a promise using `$q` as a constructor, without providing the required `resolver` function.

    //bad
    var promise = $q().then(doSomething);

    //good
    var promise = $q(function(resolve, reject) {
      waitForSomethingAsync.then(resolve);
    }).then(doSomething);